"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
var application = require("@nativescript/core/application");
var color_1 = require("@nativescript/core/color");
var image_source_1 = require("@nativescript/core/image-source");
var platform_1 = require("@nativescript/core/platform");
var frame_1 = require("@nativescript/core/ui/frame");
var utils_1 = require("@nativescript/core/utils/utils");
var loading_indicator_common_1 = require("./loading-indicator.common");
__export(require("./loading-indicator.common"));
var R_ATTR_PROGRESS_BAR_STYLE_HORIZONTAL = 0x01010078;
var PACKAGE = 'com.github.triniwiz.ns.loading.indicator';
var ViewCompatNamespace = useAndroidX()
    ? androidx.core.view
    : android.support.v4.view;
function useAndroidX() {
    return global.androidx && global.androidx.core.view;
}
var LoadingIndicator = (function () {
    function LoadingIndicator() {
        this._defaultProgressColor = new color_1.Color('#007DD6');
        this._progressId = android.view.View.generateViewId();
        this._messageId = android.view.View.generateViewId();
        this._detailsId = android.view.View.generateViewId();
        this._customViewId = android.view.View.generateViewId();
        this._loadersInstances = [];
    }
    LoadingIndicator.prototype.show = function (options) {
        var _this = this;
        var context = utils_1.ad.getApplicationContext();
        if (context) {
            options = options || {};
            options.android = options.android || {};
            options.userInteractionEnabled =
                options.userInteractionEnabled !== undefined || true;
            if (!this._popOver) {
                setTimeout(function () {
                    _this._createPopOver(context, options);
                    _this._loadersInstances.push(_this._popOver);
                });
            }
            else {
                this._updatePopOver(context, options);
            }
        }
    };
    LoadingIndicator.prototype.hide = function () {
        try {
            for (var i = 0; i < this._loadersInstances.length; i++) {
                var loader = this._loadersInstances[i];
                if (loader) {
                    if (this._isShowing(loader)) {
                        loader.dismiss();
                        this._loadersInstances.splice(i, 1);
                    }
                }
            }
            this._popOver = null;
            this._currentProgressColor = null;
        }
        catch (e) {
            console.log(e);
        }
    };
    LoadingIndicator.prototype._isShowing = function (loader) {
        return loader.isShowing();
    };
    LoadingIndicator.prototype._createPopOver = function (context, options) {
        this._popOver = new android.widget.PopupWindow();
        var ref = new WeakRef(this);
        this._popOver.setTouchable(options.userInteractionEnabled);
        var contentView = new android.widget.LinearLayout(context);
        var defaultTextColor = new color_1.Color(options.color || '#000');
        var defaultTextNativeColor = defaultTextColor.android
            ? defaultTextColor.android
            : android.graphics.Color.BLACK;
        var defaultDetailsNativeColor = new color_1.Color(255 * 0.8, defaultTextColor.r, defaultTextColor.g, defaultTextColor.b).android;
        contentView.setOnTouchListener(new android.view.View.OnTouchListener({
            onTouch: function (view, event) {
                var cancelListener = options.android.cancelListener;
                var cancelable = options.android.cancelable;
                var owner = ref.get();
                if (cancelListener && typeof cancelListener === 'function') {
                    if (owner && cancelable) {
                        owner._popOver.dismiss();
                        cancelListener(owner._popOver);
                        owner._popOver = null;
                    }
                }
                return true;
            }
        }));
        var defaultBackgroundColor = android.graphics.Color.WHITE;
        contentView.setBackgroundColor(options.dimBackground
            ? new color_1.Color(255 * 0.6, 0, 0, 0).android
            : android.graphics.Color.TRANSPARENT);
        contentView.setGravity(android.view.Gravity.CENTER);
        contentView.setLayoutParams(new android.view.ViewGroup.LayoutParams(android.view.ViewGroup.LayoutParams.FILL_PARENT, android.view.ViewGroup.LayoutParams.FILL_PARENT));
        var parentView = new android.widget.LinearLayout(context);
        parentView.setOnTouchListener(new android.view.View.OnTouchListener({
            onTouch: function (view, event) {
                return true;
            }
        }));
        ViewCompatNamespace.ViewCompat.setElevation(parentView, 9.0);
        var params = parentView.getLayoutParams();
        var parentViewParams = params
            ? params
            : new android.widget.LinearLayout.LayoutParams(android.view.ViewGroup.LayoutParams.WRAP_CONTENT, android.view.ViewGroup.LayoutParams.WRAP_CONTENT);
        var defaultPadding = 10 * platform_1.screen.mainScreen.scale;
        parentView.setPadding(defaultPadding, defaultPadding, defaultPadding, defaultPadding);
        if (options.margin !== undefined) {
            var margin = options.margin * platform_1.screen.mainScreen.scale;
            parentViewParams.setMargins(margin, margin, margin, margin);
        }
        parentView.setLayoutParams(parentViewParams);
        var backgroundColor = options.backgroundColor
            ? new color_1.Color(options.backgroundColor).android
            : defaultBackgroundColor;
        if (options.hideBezel) {
            parentView.setBackgroundColor(android.graphics.Color.TRANSPARENT);
        }
        else {
            var border = new android.graphics.drawable.ShapeDrawable();
            border.getPaint().setColor(backgroundColor);
            var cornerRadiusValue = 8;
            var cornerRadius = Array.create('float', 8);
            cornerRadius[0] = cornerRadiusValue;
            cornerRadius[1] = cornerRadiusValue;
            cornerRadius[2] = cornerRadiusValue;
            cornerRadius[3] = cornerRadiusValue;
            cornerRadius[4] = cornerRadiusValue;
            cornerRadius[5] = cornerRadiusValue;
            cornerRadius[6] = cornerRadiusValue;
            cornerRadius[7] = cornerRadiusValue;
            var shape = new android.graphics.drawable.shapes.RoundRectShape(cornerRadius, null, null);
            border.setShape(shape);
            parentView.setBackgroundDrawable(border);
        }
        parentView.setGravity(android.view.Gravity.CENTER);
        parentView.setOrientation(android.widget.LinearLayout.VERTICAL);
        var progressView;
        var customOrText = options.mode === loading_indicator_common_1.Mode.CustomView || options.mode === loading_indicator_common_1.Mode.Text;
        if (!customOrText) {
            var determinate = options.progress !== undefined ||
                options.mode === loading_indicator_common_1.Mode.Determinate ||
                options.mode === loading_indicator_common_1.Mode.DeterminateHorizontalBar ||
                options.mode === loading_indicator_common_1.Mode.AnnularDeterminate;
            if (determinate) {
                progressView = new android.widget.ProgressBar(context, null, R_ATTR_PROGRESS_BAR_STYLE_HORIZONTAL);
            }
            else {
                progressView = new android.widget.ProgressBar(context);
            }
            progressView.setId(this._progressId);
            parentView.addView(progressView);
        }
        if (options.mode === loading_indicator_common_1.Mode.CustomView) {
            if (options.customView) {
                var customView = this._createCustomView(context, options);
                if (customView) {
                    parentView.addView(customView);
                }
            }
        }
        if (options.message) {
            var messageView = new android.widget.TextView(context);
            messageView.setText(options.message);
            messageView.setId(this._messageId);
            if (options.color) {
                messageView.setTextColor(defaultTextNativeColor);
            }
            messageView.setLayoutParams(new android.widget.LinearLayout.LayoutParams(android.widget.LinearLayout.LayoutParams.WRAP_CONTENT, android.widget.LinearLayout.LayoutParams.WRAP_CONTENT));
            parentView.addView(messageView);
        }
        if (options.details) {
            var detailsView = new android.widget.TextView(context);
            detailsView.setText(options.details);
            detailsView.setId(this._detailsId);
            detailsView.setTextColor(defaultDetailsNativeColor);
            detailsView.setLayoutParams(new android.widget.LinearLayout.LayoutParams(android.widget.LinearLayout.LayoutParams.WRAP_CONTENT, android.widget.LinearLayout.LayoutParams.WRAP_CONTENT));
            parentView.addView(detailsView);
        }
        switch (options.mode) {
            case loading_indicator_common_1.Mode.CustomView:
                break;
            case loading_indicator_common_1.Mode.AnnularDeterminate:
                progressView.setIndeterminate(false);
                progressView.setMax(100);
                progressView.setProgress(0);
                progressView.setProgressDrawable(this._getProgressDrawable());
                progressView.setBackgroundDrawable(this._getBackgroundDrawable());
                progressView.setLayoutParams(new android.widget.LinearLayout.LayoutParams(60 * platform_1.screen.mainScreen.scale, 60 * platform_1.screen.mainScreen.scale));
                break;
            case loading_indicator_common_1.Mode.Determinate:
                progressView.setIndeterminate(false);
                progressView.setMax(100);
                progressView.setProgress(0);
                progressView.setProgressDrawable(this._getProgressDrawableThick());
                progressView.setBackgroundDrawable(this._getBackgroundDrawable());
                progressView.setLayoutParams(new android.widget.LinearLayout.LayoutParams(60 * platform_1.screen.mainScreen.scale, 60 * platform_1.screen.mainScreen.scale));
                break;
            case loading_indicator_common_1.Mode.DeterminateHorizontalBar:
                progressView.setIndeterminate(false);
                progressView.setMax(100);
                progressView.setProgress(0);
                break;
            case loading_indicator_common_1.Mode.Text:
                break;
            case loading_indicator_common_1.Mode.Indeterminate:
                progressView.setIndeterminate(true);
                break;
            default:
                progressView.setIndeterminate(options.progress !== undefined ? false : true);
                break;
        }
        if (options.progress !== undefined ||
            options.mode === loading_indicator_common_1.Mode.Determinate ||
            options.mode === loading_indicator_common_1.Mode.AnnularDeterminate ||
            options.mode === loading_indicator_common_1.Mode.DeterminateHorizontalBar ||
            options.mode === loading_indicator_common_1.Mode.Indeterminate ||
            !options.mode) {
            if (options.color) {
                this._setColor(options.color, progressView);
                this._currentProgressColor = new color_1.Color(options.color);
            }
            if (options.backgroundColor) {
                this._setBackgroundColor(options.backgroundColor, progressView);
            }
        }
        contentView.addView(parentView);
        this._popOver.setContentView(contentView);
        var view = frame_1.Frame.topmost().android.rootViewGroup ||
            frame_1.Frame.topmost().currentPage.android;
        if (options.android && options.android.view) {
            var nativeView = options.android.view;
            this._popOver.setWidth(nativeView.getWidth());
            this._popOver.setHeight(nativeView.getHeight());
            this._popOver.showAtLocation(nativeView, android.view.Gravity.CENTER, 0, 0);
        }
        else {
            this._popOver.setWidth(platform_1.screen.mainScreen.widthPixels);
            this._popOver.setHeight(platform_1.screen.mainScreen.heightPixels);
            this._popOver.showAtLocation(view, android.view.Gravity.CENTER, 0, 0);
        }
    };
    LoadingIndicator.prototype._updatePopOver = function (context, options) {
        var contentView = this._popOver.getContentView();
        var parentView = contentView.getChildAt(0);
        var count = parentView.getChildCount();
        var defaultTextColor = new color_1.Color(options.color || 'black');
        var defaultTextNativeColor = defaultTextColor.android
            ? defaultTextColor.android
            : android.graphics.Color.BLACK;
        var defaultDetailsNativeColor = new color_1.Color(255 * 0.8, defaultTextColor.r, defaultTextColor.g, defaultTextColor.b).android;
        if (options.mode === loading_indicator_common_1.Mode.Text) {
            var progressView = parentView.getChildAt(0);
            if (progressView) {
                var progressViewId = progressView.getId();
                if (progressViewId === this._progressId) {
                    parentView.removeView(progressView);
                    count = parentView.getChildCount();
                }
            }
        }
        if (options.mode === loading_indicator_common_1.Mode.CustomView) {
            for (var i = 0; i < count; i++) {
                var view = parentView.getChildAt(i);
                parentView.removeView(view);
            }
            var customView = this._createCustomView(context, options);
            if (customView) {
                parentView.addView(customView);
            }
            count = parentView.getChildCount();
        }
        if (options.progress &&
            options.mode !== loading_indicator_common_1.Mode.Text &&
            options.mode !== loading_indicator_common_1.Mode.CustomView) {
            var progressView = parentView.getChildAt(0);
            var progressViewId = progressView.getId();
            if (progressView instanceof android.widget.ProgressBar &&
                progressViewId === this._progressId &&
                progressView.isIndeterminate()) {
                parentView.removeView(progressView);
                progressView = this._createDeterminateProgressView(context);
                parentView.addView(progressView, 0);
            }
            if (!(progressView instanceof android.widget.ProgressBar)) {
                progressView = this._createDeterminateProgressView(context);
                parentView.addView(progressView, 0);
            }
            count = parentView.getChildCount();
            if (options.color) {
                this._setColor(options.color, progressView);
                this._currentProgressColor = new color_1.Color(options.color);
            }
            if (options.backgroundColor) {
                this._setBackgroundColor(options.backgroundColor, progressView);
            }
            progressView.setProgress(options.progress * 100);
        }
        if (!options.progress &&
            options.mode !== loading_indicator_common_1.Mode.Text &&
            options.mode !== loading_indicator_common_1.Mode.CustomView &&
            options.mode === loading_indicator_common_1.Mode.Indeterminate) {
            var progressView = new android.widget.ProgressBar(context);
            progressView.setId(this._progressId);
            parentView.addView(progressView, 0);
            if (options.color) {
                this._setColor(options.color, progressView);
                this._currentProgressColor = new color_1.Color(options.color);
            }
            if (options.backgroundColor) {
                this._setBackgroundColor(options.backgroundColor, progressView);
            }
            count = parentView.getChildCount();
        }
        if (options.message) {
            var messageView = void 0;
            var view = void 0;
            var firstView = parentView.getChildAt(0);
            switch (count) {
                case 1:
                    if (firstView.getId() === this._messageId) {
                        firstView.setTextColor(defaultTextNativeColor);
                        firstView.setText(options.message);
                    }
                    else {
                        messageView = new android.widget.TextView(context);
                        messageView.setId(this._messageId);
                        messageView.setText(options.message);
                        messageView.setTextColor(defaultTextNativeColor);
                        messageView.setLayoutParams(new android.widget.LinearLayout.LayoutParams(android.widget.LinearLayout.LayoutParams.WRAP_CONTENT, android.widget.LinearLayout.LayoutParams.WRAP_CONTENT));
                        parentView.addView(messageView);
                    }
                    break;
                case 2:
                    view = parentView.getChildAt(1);
                    var viewId = view.getId();
                    if (viewId === this._messageId) {
                        view.setText(options.message);
                        view.setTextColor(defaultTextNativeColor);
                    }
                    else if (viewId === this._detailsId) {
                        messageView = new android.widget.TextView(context);
                        messageView.setId(this._messageId);
                        messageView.setText(options.message);
                        messageView.setTextColor(defaultTextNativeColor);
                        messageView.setLayoutParams(new android.widget.LinearLayout.LayoutParams(android.widget.LinearLayout.LayoutParams.WRAP_CONTENT, android.widget.LinearLayout.LayoutParams.WRAP_CONTENT));
                        parentView.addView(messageView, 1);
                    }
                    break;
                case 3:
                    view = parentView.getChildAt(2);
                    view.setTextColor(defaultTextNativeColor);
                    view.setText(options.message);
                    break;
                default:
                    break;
            }
            count = parentView.getChildCount();
        }
        if (options.details) {
            var detailsView = void 0;
            switch (count) {
                case 1:
                    var firstView = parentView.getChildAt(0);
                    if (firstView === this._detailsId) {
                        firstView.setTextColor(defaultDetailsNativeColor);
                        firstView.setText(options.details);
                    }
                    else {
                        detailsView = new android.widget.TextView(context);
                        detailsView.setId(this._detailsId);
                        detailsView.setTextColor(defaultDetailsNativeColor);
                        detailsView.setText(options.details);
                        detailsView.setLayoutParams(new android.widget.LinearLayout.LayoutParams(android.widget.LinearLayout.LayoutParams.WRAP_CONTENT, android.widget.LinearLayout.LayoutParams.WRAP_CONTENT));
                        parentView.addView(detailsView);
                    }
                    break;
                case 2:
                    detailsView = parentView.getChildAt(1);
                    var detailsViewId = detailsView.getId();
                    if (detailsViewId === this._detailsId) {
                        detailsView.setTextColor(defaultDetailsNativeColor);
                        detailsView.setText(options.details);
                    }
                    else if (detailsViewId === this._messageId) {
                        detailsView = new android.widget.TextView(context);
                        detailsView.setId(this._detailsId);
                        detailsView.setTextColor(defaultDetailsNativeColor);
                        detailsView.setText(options.details);
                        detailsView.setLayoutParams(new android.widget.LinearLayout.LayoutParams(android.widget.LinearLayout.LayoutParams.WRAP_CONTENT, android.widget.LinearLayout.LayoutParams.WRAP_CONTENT));
                        parentView.addView(detailsView, 2);
                    }
                    break;
                case 3:
                    detailsView = parentView.getChildAt(2);
                    detailsView.setTextColor(defaultDetailsNativeColor);
                    detailsView.setText(options.details);
                    break;
                default:
                    break;
            }
        }
        this._popOver.update();
    };
    LoadingIndicator.prototype._createCustomView = function (context, options) {
        var customView;
        if (options.customView instanceof android.graphics.Bitmap) {
            customView = new android.widget.ImageView(context);
            customView.setImageBitmap(options.customView);
        }
        else if (options.customView instanceof android.view.View) {
            customView = options.customView;
        }
        else if (typeof options.customView === 'string') {
            customView = new android.widget.ImageView(context);
            var fileName = options.customView
                .replace('.jpg', '')
                .replace('.png', '')
                .replace('.jpeg', '');
            var image = image_source_1.fromFileOrResource('res://' + fileName);
            if (image && image.android) {
                customView.setImageBitmap(image.android);
            }
        }
        customView.setId(this._customViewId);
        return customView;
    };
    LoadingIndicator.prototype._createDeterminateProgressView = function (context) {
        var progressView = new android.widget.ProgressBar(context, null, R_ATTR_PROGRESS_BAR_STYLE_HORIZONTAL);
        progressView.setId(this._progressId);
        progressView.setMax(100);
        progressView.setProgress(0);
        progressView.setProgressDrawable(this._getProgressDrawable());
        progressView.setBackgroundDrawable(this._getBackgroundDrawable());
        progressView.setLayoutParams(new android.widget.LinearLayout.LayoutParams(60 * platform_1.screen.mainScreen.scale, 60 * platform_1.screen.mainScreen.scale));
        return progressView;
    };
    LoadingIndicator.prototype._setBackgroundColor = function (color, view) {
        var progressDrawable = view.getProgressDrawable();
        var indeterminateDrawable = view.getIndeterminateDrawable();
        if (progressDrawable instanceof android.graphics.drawable.LayerDrawable &&
            progressDrawable.getNumberOfLayers() > 0) {
            var backgroundDrawable = progressDrawable.getDrawable(0);
            if (backgroundDrawable) {
                backgroundDrawable.setColorFilter(new color_1.Color(color).android, android.graphics.PorterDuff.Mode.SRC_IN);
            }
        }
        if (indeterminateDrawable instanceof
            android.graphics.drawable.LayerDrawable &&
            indeterminateDrawable.getNumberOfLayers() > 0) {
            var backgroundDrawable = indeterminateDrawable.getDrawable(0);
            if (backgroundDrawable) {
                backgroundDrawable.setColorFilter(new color_1.Color(color).android, android.graphics.PorterDuff.Mode.SRC_IN);
            }
        }
    };
    LoadingIndicator.prototype._setColor = function (color, view) {
        var progressDrawable = view.getProgressDrawable();
        var indeterminateDrawable = view.getIndeterminateDrawable();
        if (progressDrawable) {
            progressDrawable.setColorFilter(new color_1.Color(color).android, android.graphics.PorterDuff.Mode.SRC_IN);
        }
        if (indeterminateDrawable) {
            indeterminateDrawable.setColorFilter(new color_1.Color(color).android, android.graphics.PorterDuff.Mode.SRC_IN);
        }
    };
    LoadingIndicator.prototype._getResources = function () {
        var ctx = application.android.foregroundActivity;
        return ctx.getResources();
    };
    LoadingIndicator.prototype._getBackgroundDrawable = function () {
        return this._getResources().getDrawable(com.github.triniwiz.ns.loading.indicator.R.drawable.circle_shape);
    };
    LoadingIndicator.prototype._getProgressDrawable = function () {
        return this._getResources().getDrawable(com.github.triniwiz.ns.loading.indicator.R.drawable.circular_progress_bar);
    };
    LoadingIndicator.prototype._getProgressDrawableThick = function () {
        return this._getResources().getDrawable(com.github.triniwiz.ns.loading.indicator.R.drawable
            .circular_progress_bar_thick);
    };
    return LoadingIndicator;
}());
exports.LoadingIndicator = LoadingIndicator;
//# sourceMappingURL=loading-indicator.android.js.map